"use client";
import React, { useState, useEffect } from "react";
import { cn } from "@/lib/utils";
import ThemeButton from "./theme-button";
import { useSidebar, useThemeStore } from "@/store";
import VerticalHeader from "./vertical-header";
import HorizontalHeader from "./horizontal-header";
import Inbox from "./inbox";
import HorizontalMenu from "./horizontal-menu";
import Language from "./language";
import { useMediaQuery } from "@/hooks/use-media-query";
import MobileMenuHandler from "./mobile-menu-handler";
import ClassicHeader from "./layout/classic-header";
import FullScreen from "./full-screen";
import { Icon } from "@iconify/react";
import { useTranslations } from "next-intl";
import { removeUserToken } from 'action/cookies'
import { useTransition } from "react";


import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuGroup,
  DropdownMenuItem,
  DropdownMenuLabel,
  DropdownMenuSeparator,
  DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu";

import profileicon from "../../../myprofile.png";
import Image from "next/image";
import DriveFolderUploadOutlinedIcon from "@mui/icons-material/DriveFolderUploadOutlined";
import { Download } from "@mui/icons-material";
import StickyNote2Icon from '@mui/icons-material/StickyNote2';
import LockOpenOutlinedIcon from "@mui/icons-material/LockOpenOutlined";
import LockResetIcon from '@mui/icons-material/LockReset';
import Link from "next/link";
import { getWithToken } from "@/Helper/common";
import { useRouter } from "next/navigation";
import toast, { Toaster } from "react-hot-toast";
import defaultImage from '../../../public/man.png'; // Ensure this path is correct

const NavTools = ({ isDesktop, isMobile, sidebarType, userKycData }) => {

  // console.log('NavTools', userKycData);

  const router = useRouter();
  const lang = useTranslations("ProfileMenu");
  const [isPending, startTransition] = useTransition();

  const logout = async () => {
    typeof window !== 'undefined' ? localStorage.removeItem('token') : null;

    // startTransition(async () => {
    //   await removeUserToken(); // Call the Server Action
    //   toast.success("Logout Successfully", {
    //     position: "bottom-center",
    //     style: { borderRadius: "10px", background: "#333", color: "#fff" },
    //   });

    //   router.replace("/login"); // Navigate to login page
    // });

    removeUserToken();
    
    toast.success('Logout Successfully', {
      position: "bottom-center",
      style: { borderRadius: "10px", background: "#333", color: "#fff" },
    });
    location.href = '/login';
  };

  const [menu, setMenu] = useState(false);
  const [update, setUpadte] = useState(false);
  const handleClick = () => {
    setMenu(true);
    setUpadte(true)
  };

  const [imageSrc, setImageSrc] = useState('/man.png');
  const [userData, setUserDetailsData] = useState(userKycData?.userData);

  useEffect(() => {
    // fetchKycData();

  }, []);

  var apiCall = true;

  // const fetchKycData = async () => {
  //   try {

  //     if (apiCall) {

  //       apiCall = false;

  //       const apiResData = await getWithToken("get-kyc-details");
  //       // console.log(apiResData);
  //       if (apiResData.error === false) {
  //         // setKycDetailsData(apiResData.data);
  //         setUserDetailsData(apiResData.userData);
  //         //console.log("userData:", apiResData.userData);
  //       }
  //     }

  //   } catch (error) {
  //     console.error("Error fetching slider:", error);
  //     // setLoading(false);
  //   }
  // };

  const handleError = () => {
    setImageSrc(defaultImage); // Fallback image
  };

  useEffect(() => {
    if (userData?.image) {
      // console.log(userData.image);
      setImageSrc(userData.image);

    } else {
      // console.log('/man.png');
      setImageSrc('/man.png');
    }
  }, [userData?.image]);

  return (

    userData ?

      <div className="nav-tools flex items-center  gap-2">
        {isDesktop && <Language />}
        {isDesktop && <FullScreen />}

        <ThemeButton />
        {
          userData?.designation_id != 1 ?

            <Inbox />
            
          : null
        }
        
        {/* <NotificationMessage /> */}

        <div className=" pl-2">
          <React.Fragment>
            <DropdownMenu>
              <DropdownMenuTrigger asChild className=" cursor-pointer">
                <div className=" flex items-center  space-x-3">
                  {
                    userData && userData?.image ? (
                      <img
                        src={userData.image}
                        alt="User Image"
                        width={35}
                        height={35}
                        onError={(e) => {
                          e.target.onerror = null; // Prevent infinite loop in case the default image also fails
                          e.target.src = '/man.png'; // Set default image on error
                        }}
                      />
                    ) : (
                      <img
                        src="/man.png"
                        alt="Default User Image"
                        width={35}
                        height={35}
                      />
                    )
                  }


                </div>
              </DropdownMenuTrigger>
              <DropdownMenuContent className="w-56 mr-4" align="start">
                <DropdownMenuLabel> {lang("My_Account")}</DropdownMenuLabel>
                <DropdownMenuSeparator />
                <DropdownMenuGroup>
                  <Link href="/admin/profile" prefetch={true}>
                    <DropdownMenuItem onClick={handleClick}>
                      <Icon icon="heroicons:user" className="w-5 h-5 mr-2 " />
                      {lang("Profile")}
                    </DropdownMenuItem>
                  </Link>


                  {(userData.designation_id !== 1 && userData.designation_id !== 2) &&(<Link href="/admin/certificate" prefetch={true}>
                    <DropdownMenuItem >
                      <Download
                        icon="heroicons:credit-card"
                        className="w-5 h-5 mr-2 hover:cursor-pointer"
                      />{" "}
                      Download certificate
                    </DropdownMenuItem>
                  </Link>)}

                  {/* <DropdownMenuItem onClick={handleClick}>
                    <DriveFolderUploadOutlinedIcon
                      icon="heroicons:cloud"
                      className="w-5 h-5 mr-2 "
                    />{" "}
                    {lang("Upload_Document")}
                  </DropdownMenuItem> */}

                  <DropdownMenuItem onClick={handleClick}>
                    <Link href="/admin/update-mpin" prefetch={true}>
                      <LockResetIcon
                        icon="heroicons:credit-card"
                        className="w-5 h-5 mr-2 "
                      />{" "}
                      {lang("Change_MPIN")}
                    </Link>
                  </DropdownMenuItem>

                  <DropdownMenuItem onClick={handleClick}>
                    <Link href="/admin/update-password" prefetch={true}>
                      <LockOpenOutlinedIcon
                        icon="heroicons:credit-card"
                        className="w-5 h-5 mr-2 "
                      />{" "}
                      {lang("Change_Password")}
                    </Link>
                  </DropdownMenuItem>

                  {/* <DropdownMenuItem onClick={handleClick}>
                  <Link href="/admin/kyc-update" prefetch={true}>
                    <StickyNote2Icon
                      icon="heroicons:cloud"
                      className="w-5 h-5 mr-2 "
                    />{" "}
                    {lang("Update_KYC")}
                  </Link>
                </DropdownMenuItem> */}



                </DropdownMenuGroup>
                <DropdownMenuSeparator />

                <DropdownMenuItem onClick={logout}>
                  <Icon icon="heroicons:power" className="w-5 h-5 mr-2 " />
                  {lang("Log_out")}
                  {/* <DropdownMenuShortcut>⇧⌘Q</DropdownMenuShortcut> */}
                </DropdownMenuItem>
              </DropdownMenuContent>
            </DropdownMenu>
          </React.Fragment>
        </div>
        {!isDesktop && sidebarType !== "module" && <MobileMenuHandler />}
      </div>

      : null
  );
};

const Header = ({ handleOpenSearch, userKycData }) => {

  // console.log('userKycData', userKycData);
  const [kycDetailsData, setKycDetailsData] = useState(userKycData?.data);
  const [userDetailsData, setUserDetailsData] = useState(userKycData?.userData);
  const { collapsed, sidebarType, setCollapsed, subMenu, setSidebarType, showText, setShowText,initializeShowText } =
    useSidebar();

    

  const { layout, navbarType, setLayout } = useThemeStore();

  const isDesktop = useMediaQuery("(min-width: 1280px)");

  const isMobile = useMediaQuery("(min-width: 768px)");

  useEffect(() => {
    // fetchKycData();
    // const intervalId = setInterval(fetchKycData, 8000);
    // return () => clearInterval(intervalId);
  }, []);


  // set header style to classic if isDesktop
  React.useEffect(() => {
    if (!isDesktop && layout === "horizontal") {
      setSidebarType("classic");
    }
  }, [isDesktop]);

  // if horizontal layout
  if (layout === "horizontal" && navbarType !== "hidden") {
    return (
      userKycData ?
        <ClassicHeader
          className={cn(" ", {
            "sticky top-0 z-50": navbarType === "sticky",
          })}
        >
          <div className="w-full bg-card/90 backdrop-blur-lg md:px-6 px-[15px] py-3 border-b">
            <div className="flex justify-between items-center h-full">
              <HorizontalHeader handleOpenSearch={handleOpenSearch} />
              <NavTools
                isDesktop={isDesktop}
                isMobile={isMobile}
                sidebarType={sidebarType}
                userKycData={userKycData}
              />
            </div>
          </div>
          {isDesktop && (
            <div className=" bg-card bg-card/90 backdrop-blur-lg  w-full px-6  shadow-md">
              <HorizontalMenu />
            </div>
          )}
        </ClassicHeader>
        : null
    );
  }
  if (layout === "semibox" && navbarType !== "hidden") {
    return (
      userKycData ?
        <ClassicHeader
          className={cn("  has-sticky-header rounded-md   ", {
            "xl:ml-[140px]": collapsed,
            "xl:ml-[272px]": !collapsed,
            "sticky top-6": navbarType === "sticky",
          })}
        >
          <div className={cn("xl:mx-20 mx-4")}>
            <div className="w-full bg-card/90 backdrop-blur-lg md:px-6 px-[15px] py-3 rounded-md my-6 shadow-md border-b">
              <div className="flex justify-between items-center h-full">
                <VerticalHeader
                  sidebarType={sidebarType}
                  handleOpenSearch={handleOpenSearch}
                  kycDetailsData={kycDetailsData}
                  userDetailsData={userDetailsData}
                />
                <NavTools
                  isDesktop={isDesktop}
                  isMobile={isMobile}
                  sidebarType={sidebarType}
                  userKycData={userKycData}
                />
              </div>
            </div>
          </div>
        </ClassicHeader>
        : null
    );
  }
  if (
    sidebarType !== "module" &&
    navbarType !== "floating" &&
    navbarType !== "hidden"
  ) {
    return (
      userKycData ?
        <ClassicHeader
          className={cn("", {
            "xl:ml-[395px]": !collapsed && !showText,
            "xl:ml-[200px]": collapsed && !showText,
            "xl:ml-[265px]": !collapsed && showText,
            "xl:ml-[66px]": collapsed && showText,
            "sticky top-0": navbarType === "sticky",
          })}
        >
          <div className="w-full bg-card/90 backdrop-blur-lg md:px-6 px-[15px] py-3 border-b">
            <div className="flex justify-between items-center h-full">
              <VerticalHeader
                sidebarType={sidebarType}
                handleOpenSearch={handleOpenSearch}
                kycDetailsData={kycDetailsData}
                userDetailsData={userDetailsData}
              />
              <NavTools
                isDesktop={isDesktop}
                isMobile={isMobile}
                sidebarType={sidebarType}
                userKycData={userKycData}
              />
            </div>
          </div>
        </ClassicHeader>

        : null
    );
  }
  if (
    sidebarType !== "module" &&
    navbarType !== "floating" &&
    navbarType !== "hidden"
  ) {
    return (
      <ClassicHeader
        className={cn("", {
          // "xl:ml-[420px]": !collapsed && !showText,
          "xl:ml-[395px]": !collapsed && !showText,
          "xl:ml-[200px]": collapsed && !showText,
          // "xl:ml-[290px]": !collapsed && showText,
          "xl:ml-[265px]": !collapsed && showText,
          "xl:ml-[66px]": collapsed && showText,
          "sticky top-0": navbarType === "sticky",
        })}
      >
        <div className="w-full bg-card/90 backdrop-blur-lg md:px-6 px-[15px] py-3 border-b">
          <div className="flex justify-between items-center h-full">
            <VerticalHeader
              sidebarType={sidebarType}
              handleOpenSearch={handleOpenSearch}
              kycDetailsData={kycDetailsData}
              userDetailsData={userDetailsData}
            />
            <NavTools
              isDesktop={isDesktop}
              isMobile={isMobile}
              sidebarType={sidebarType}
            />
          </div>
        </div>
      </ClassicHeader>
    );
  }
  if (navbarType === "hidden") {
    return null;
  }
  if (navbarType === "floating") {
    return (
      userKycData ?
        <ClassicHeader
          className={cn("  has-sticky-header rounded-md sticky top-6  px-6  ", {
            "ml-[72px]": collapsed,
            "xl:ml-[300px] ": !collapsed && sidebarType === "module",
            "xl:ml-[248px] ": !collapsed && sidebarType !== "module",
          })}
        >
          <div className="w-full bg-card/90 backdrop-blur-lg md:px-6 px-[15px] py-3 rounded-md my-6 shadow-md border-b">
            <div className="flex justify-between items-center h-full">
              <VerticalHeader
                sidebarType={sidebarType}
                handleOpenSearch={handleOpenSearch}
                kycDetailsData={kycDetailsData}
                userDetailsData={userDetailsData}
              />
              <NavTools
                isDesktop={isDesktop}
                isMobile={isMobile}
                sidebarType={sidebarType}
                userKycData={userKycData}
              />
            </div>
          </div>
        </ClassicHeader>
        : null
    );
  }

  return (

    userKycData ?

      <ClassicHeader
        className={cn("", {
          "xl:ml-[412px]": !collapsed,
          "xl:ml-[140px]": collapsed,
          "sticky top-0": navbarType === "sticky",
        })}
      >
        <div className="w-full bg-card/90 backdrop-blur-lg md:px-6 px-[15px] py-3 border-b">
          <div className="flex justify-between items-center h-full">
            <VerticalHeader
              sidebarType={sidebarType}
              handleOpenSearch={handleOpenSearch}
              kycDetailsData={kycDetailsData}
              userDetailsData={userDetailsData}
            />
            <NavTools
              isDesktop={isDesktop}
              isMobile={isMobile}
              sidebarType={sidebarType}
              userKycData={userKycData}
            />
          </div>
        </div>
      </ClassicHeader>
      : null
  );
};

export default Header;
